@@ -10,7 +10,11 @@ rm -rf dist/ build/ *.egg-info
 # 2. Update __version__ in __init__.py
 # 3. Create git tag
 # 4. Generate changelog
-if ! uv run cz bump --yes 2>/dev/null; then
+# Show what commitizen is doing
+uv run cz changelog || true
+uv run cz version --project
+
+if ! uv run cz bump --yes; then
     echo "No version bump needed (or tag already exists)"
     exit 0
 fi
@@ -18,6 +22,9 @@ fi
 # Get the new version directly from __init__.py
 VERSION=$(grep "__version__" src/git_llm_commit/__init__.py | cut -d'"' -f2)
 
+# Push the version bump commit and changelog
+git push origin main
+
 # Try to push the new tag, but don't fail if it exists
 if git push origin "v${VERSION}" 2>/dev/null; then
     echo "Pushed tag v${VERSION}"
